# Kognic Base Clients

Python 3 library for providing a base clients for interacting with the Kognic platform

# Changelog

All notable changes to this library will be documented in this file

## [1.0.0] - 2022-10-18
- Annotell becomes Kognic

## [0.1.1] - 2022-08-16
- Corrected user agent
- Bugfix for timeout

## [0.1.0] - 2022-05-12
- Update `annotell-auth` to 2.0.1
- Support for pagination on API requests

## [0.0.1] - 2022-04-01

- Library created
